#
# spec file for package grpc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname libgrpc6
Name:           grpc
Version:        1.10.0
Release:        lp150.1.1
Summary:        HTTP/2-based Remote Procedure Call implementation
License:        Apache-2.0
Group:          Development/Tools/Building
Url:            http://grpc.io/
Source:         https://github.com/grpc/grpc/archive/v%version.tar.gz
Patch1:         grpc-build.diff
Patch2:         grpc-versioning.diff
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libcares)
BuildRequires:  pkgconfig(openssl) >= 1.0.1
BuildRequires:  pkgconfig(protobuf) >= 3.5
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The reference implementation of the gRPC protocol, done on top of
HTTP/2 with support for synchronous and asynchronous calls. gRPC uses
Protocol Buffers as the Interface Definition Language by default.

%package -n %lname
Summary:        HTTP/2-based Remote Procedure Call implementation
Group:          System/Libraries

%description -n %lname
The reference implementation of the gRPC protocol, done on top of
HTTP/2 with support for synchronous and asynchronous calls. gRPC uses
Protocol Buffers as the Interface Definition Language by default.

%package devel
Summary:        Development files for grpc, a HTTP/2 Remote Procedure Call implementation
Group:          Development/Tools/Building
Requires:       %lname = %version

%description devel
This subpackage contains libraries and header files for developing
applications that want to make use of the gRPC reference implementation.

%prep
%setup -q
%patch -P 1 -P 2 -p1

%build 
make LIBDIR=x CONFIG=opt \
	x/opt/pkgconfig/grpc.pc x/opt/pkgconfig/grpc_unsecure.pc \
	x/opt/pkgconfig/grpc++.pc x/opt/pkgconfig/grpc++_unsecure.pc
%cmake \
	-DgRPC_PROTOBUF_PROVIDER=package \
	-DgRPC_SSL_PROVIDER=package \
	-DgRPC_ZLIB_PROVIDER=package \
	-DgRPC_CARES_PROVIDER=package \
	-DgRPC_INSTALL_BINDIR="%_bindir" \
	-DgRPC_INSTALL_INCLUDEDIR="%_includedir" \
	-DgRPC_INSTALL_LIBDIR="%_libdir"

#[ 36%] Running gRPC C++ protocol buffer compiler on src/proto/grpc/reflection/v1alpha/reflection.proto
#cd /home/abuild/rpmbuild/BUILD/grpc-1.2.3 && /usr/bin/protoc --grpc_out=/home/abuild/rpmbuild/BUILD/grpc-1.2.3/build/gens --cpp_out=/home/abuild/rpmbuild/BUILD/grpc-1.2.3/build/gens --plugin=protoc-gen-grpc=/home/abuild/rpmbuild/BUILD/grpc-1.2.3/build/grpc_cpp_plugin -I . src/proto/grpc/reflection/v1alpha/reflection.proto
#/home/abuild/rpmbuild/BUILD/grpc-1.2.3/build/grpc_cpp_plugin: error while loading shared libraries: libgrpc_plugin_support.so: cannot open shared object file: No such file or directory
#--grpc_out: protoc-gen-grpc: Plugin failed with status code 127.
export LD_LIBRARY_PATH="$PWD"
%make_jobs

%install
b="%buildroot"
mkdir -p "$b/%_libdir/pkgconfig"
cp x/opt/pkgconfig/*.pc "$b/%_libdir/pkgconfig/"
%cmake_install
#for i in "$b/%_libdir"/libg*-%version.so; do
#	ln -s "${i##*/}" "${i%%-%version.so}.so"
#done

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libg*.so.6

%files devel
%defattr(-,root,root)
%license LICENSE
%_bindir/*
%_includedir/*
%_libdir/pkgconfig/*.pc
%_libdir/libgpr.so
%_libdir/libgrpc++.so
%_libdir/libgrpc++_cronet.so
%_libdir/libgrpc++_error_details.so
%_libdir/libgrpc++_reflection.so
%_libdir/libgrpc++_unsecure.so
%_libdir/libgrpc.so
%_libdir/libgrpc_cronet.so
%_libdir/libgrpc_csharp_ext.so
%_libdir/libgrpc_plugin_support.so
%_libdir/libgrpc_unsecure.so
/usr/lib/cmake

%changelog
* Wed Mar 28 2018 jengelh@inai.de
- Update to new upstream release 1.10.0
  * Several features of core have been removed from the surface
    or GPR API as they were not used in any wrapped language
    (except C++) or in external applications.
  * Changed resolver and LB policy APIs to C++
  * C++ headers are moved from <grpc++/> to <grpcpp/>.
* Mon Feb  5 2018 jengelh@inai.de
- Update to new upstream release 1.9.0
  * LB policies request re-resolution without shutting down
  * On server, include receiving HTTP/2 settings in handshake
    timeout.
  * Add thread naming support on platforms that support it.
* Tue Jan 30 2018 jengelh@inai.de
- Update to new upstream release 1.8.6
  * Fix server segfault on invalid HTTP/2
* Fri Jan 19 2018 jengelh@inai.de
- Update to new upstream release 1.8.5
  * Fix a couple of memory leak issues in the PHP parts
* Tue Jan 16 2018 jengelh@inai.de
- Update to new upstream release 1.8.4
  * Fix HTTP/2 PING issues
  * Fix issues with poll engine
* Tue Jan  2 2018 crrodriguez@opensuse.org
- version 1.8.3
  * Eliminate superfluous log error messages
* Thu Dec 21 2017 jengelh@inai.de
- Update to new upstream release 1.8.2
  * Several LB policies fixes (grpclb and pick_first)
* Mon Dec 11 2017 jengelh@inai.de
- Update to new upstream release 1.7.3
  * Bugfixes in Load Balancing policies
  * Add flow-control and bugfixes to in-process transport
  * (C++) Async API extensions to improve multithreading support
    and reduce the need for explicit synchronization
  * (C++) Unary call API for generic (non-protobuf) RPCs
- Drop grpc-zlib.diff, grpc-protobuf.diff (fix included upstream)
- Add grpc-build.diff
* Wed Apr 19 2017 jengelh@inai.de
- Initial package (version 1.2.3) for build.opensuse.org
